
from setuptools import setup , find_packages

setup(name='atomic_loop_pkg_test',
      version='0.1',
      description='This is a test Package',
      long_description="This is just for a testing purpose",
      author='Mangesh',
      packages=['atomic_loop_pkg_test'],
      requires=[])